@@ -563,7 +563,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             np.array: Predicted values.
         """
-        
+
         print('loading model from mlflow...')
         try:
             model = self._mlflow_load_model() 
@@ -580,14 +580,13 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
                 self.model = model
 
             def predict(self, X):
-                X = X.astype(dtype=self.input_example.dtypes)
-                return self.model.predict(X).values
+                return self.model.predict(X, context=self.context).values
             
         dask_component_graph = ParallelPostFit(avm_wrapper(model))
         return dask_component_graph.predict(X) 
 
 
-    def parallel_predict(self, X, input_example=None, npartitions=64, model_name="avm", model_version="Production", cols=['unit_id','avm','avm_lower','avm_upper','conf','ts','latest_production_version','latest_staging_version']):
+    def parallel_predict(self, X, model_name='avm', model_version='Production', context={'conf_min':0.5, 'batch_sample_sets':1, 'min_sample_sz':5, 'max_sample_sz':15, 'pred_interval':0.68}, cols=['unit_id','avm','avm_lower','avm_upper','conf','ts','latest_production_version','latest_staging_version']):
         """Make predictions using selected features.
 
         Arguments:
@@ -599,7 +598,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         self.model_name=model_name
         self.model_version=model_version
-        self.input_example = input_example
+        self.context = context
 
         if not isinstance(X, dd._Frame):
             print('Building a dask dataframe...')
